@@ -7,12 +7,12 @@ sticking incoming connections onto a Queue::
 
     server = HTTPServer(...)
     server.start()
-    while True:
-        tick()
-        # This blocks until a request comes in:
-        child = socket.accept()
-        conn = HTTPConnection(child, ...)
-        server.requests.put(conn)
+    ->  while True:
+            tick()
+            # This blocks until a request comes in:
+            child = socket.accept()
+            conn = HTTPConnection(child, ...)
+            server.requests.put(conn)
 
 Worker threads are kept in a pool and poll the Queue, popping off and then
 handling each connection in turn. Each connection can consist of an arbitrary
@@ -39,6 +39,21 @@ number of requests and their responses, so we run a nested loop::
                 if req.close_connection:
                     return
 
+For running a server you can invoke :func:`start() <HTTPServer.start()>` (it
+will run the server forever) or use invoking :func:`prepare()
+<HTTPServer.prepare()>` and :func:`serve() <HTTPServer.serve()>` like this::
+
+    server = HTTPServer(...)
+    server.prepare()
+    try:
+        threading.Thread(target=server.serve).start()
+
+        # waiting/detecting some appropriate stop condition here
+        ...
+
+    finally:
+        server.stop()
+
 And now for a trivial doctest to exercise the test suite
 
 >>> 'HTTPServer' in globals()
@@ -232,6 +247,7 @@ class SizeCheckWrapper:
 
         Returns:
             bytes: Chunk from rfile, limited by size if specified.
+
         """
         data = self.rfile.read(size)
         self.bytes_read += len(data)
@@ -246,6 +262,7 @@ class SizeCheckWrapper:
 
         Returns:
             bytes: One line from rfile.
+
         """
         if size is not None:
             data = self.rfile.readline(size)
@@ -273,6 +290,7 @@ class SizeCheckWrapper:
 
         Returns:
             list[bytes]: Lines of bytes read from rfile.
+
         """
         # Shamelessly stolen from StringIO
         total = 0
@@ -313,6 +331,7 @@ class KnownLengthRFile:
         Args:
             rfile (file): file of a known size
             content_length (int): length of the file being read
+
         """
         self.rfile = rfile
         self.remaining = content_length
@@ -325,6 +344,7 @@ class KnownLengthRFile:
 
         Returns:
             bytes: Chunk from rfile, limited by size if specified.
+
         """
         if self.remaining == 0:
             return b''
@@ -345,6 +365,7 @@ class KnownLengthRFile:
 
         Returns:
             bytes: One line from rfile.
+
         """
         if self.remaining == 0:
             return b''
@@ -365,6 +386,7 @@ class KnownLengthRFile:
 
         Returns:
             list[bytes]: Lines of bytes read from rfile.
+
         """
         # Shamelessly stolen from StringIO
         total = 0
@@ -464,6 +486,7 @@ class ChunkedRFile:
 
         Returns:
             bytes: Chunk from rfile, limited by size if specified.
+
         """
         data = EMPTY
 
@@ -496,6 +519,7 @@ class ChunkedRFile:
 
         Returns:
             bytes: One line from rfile.
+
         """
         data = EMPTY
 
@@ -538,6 +562,7 @@ class ChunkedRFile:
 
         Returns:
             list[bytes]: Lines of bytes read from rfile.
+
         """
         # Shamelessly stolen from StringIO
         total = 0
@@ -556,6 +581,7 @@ class ChunkedRFile:
 
         Returns:
             Generator: yields CRLF separated lines.
+
         """
         if not self.closed:
             raise ValueError(
@@ -690,6 +716,7 @@ class HTTPRequest:
 
         Returns:
             bool: True if the request line is valid or False if it's malformed.
+
         """
         # HTTP/1.1 connections are persistent by default. If a client
         # requests a page, then idles (leaves the connection open),
@@ -1284,6 +1311,7 @@ class HTTPConnection:
         Raises:
             NotImplementedError: in case of unsupported socket type
             RuntimeError: in case of SO_PEERCRED lookup unsupported or disabled
+
         """
         PEERCRED_STRUCT_DEF = '3i'
 
@@ -1341,6 +1369,7 @@ class HTTPConnection:
         Raises:
             NotImplementedError: in case of unsupported OS
             RuntimeError: in case of UID/GID lookup unsupported or disabled
+
         """
         if IS_WINDOWS:
             raise NotImplementedError(
@@ -1398,7 +1427,10 @@ except ImportError:
         _SetHandleInformation.restype = ctypes.wintypes.BOOL
     except ImportError:
         def prevent_socket_inheritance(sock):
-            """Dummy function, since neither fcntl nor ctypes are available."""
+            """Stub inheritance prevention.
+
+            Dummy function, since neither fcntl nor ctypes are available.
+            """
             pass
     else:
         def prevent_socket_inheritance(sock):
@@ -1615,12 +1647,12 @@ class HTTPServer:
             self.stop()
             raise
 
-    def start(self):
-        """Run the server forever."""
-        # We don't have to trap KeyboardInterrupt or SystemExit here,
-        # because cherrpy.server already does so, calling self.stop() for us.
-        # If you're using this server with another framework, you should
-        # trap those exceptions in whatever code block calls start().
+    def prepare(self):
+        """Prepare server to serving requests.
+
+        It binds a socket's port, setups the socket to ``listen()`` and does
+        other preparing things.
+        """
         self._interrupt = None
 
         if self.software is None:
@@ -1692,6 +1724,9 @@ class HTTPServer:
 
         self.ready = True
         self._start_time = time.time()
+
+    def serve(self):
+        """Serve requests, after invoking :func:`prepare()`."""
         while self.ready:
             try:
                 self.tick()
@@ -1708,6 +1743,18 @@ class HTTPServer:
                 if self.interrupt:
                     raise self.interrupt
 
+    def start(self):
+        """Run the server forever.
+
+        It is shortcut for invoking :func:`prepare()` then :func:`serve()`.
+        """
+        # We don't have to trap KeyboardInterrupt or SystemExit here,
+        # because cherrypy.server already does so, calling self.stop() for us.
+        # If you're using this server with another framework, you should
+        # trap those exceptions in whatever code block calls start().
+        self.prepare()
+        self.serve()
+
     def error_log(self, msg='', level=20, traceback=False):
         """Write error message to log.
 
